@@ -14,7 +14,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * SCCS: @(#) tclEvent.c 1.127 96/03/22 12:12:33
+ * SCCS: @(#) tclEvent.c 1.131 96/08/26 13:11:03
  */
 
 #include "tclInt.h"
@@ -43,7 +43,7 @@ typedef struct FileHandler {
 static FileHandler *firstFileHandlerPtr = (FileHandler *) NULL;
 				/* List of all file handlers. */
 static int fileEventSourceCreated = 0;
-				/* Non-zero means that the file event source
+				/* Zero means that the file event source
 				 * hasn't been registerd with the Tcl
 				 * notifier yet. */
 
@@ -467,7 +467,7 @@ FileHandlerSetupProc(clientData, flags)
     for (filePtr = firstFileHandlerPtr; filePtr != NULL;
 	    filePtr = filePtr->nextPtr) {
 	if (filePtr->mask != 0) {
-	    Tcl_WatchFile(filePtr->file, filePtr->mask);
+            Tcl_WatchFile(filePtr->file, filePtr->mask);
 	}
     }
 }
@@ -508,7 +508,7 @@ FileHandlerCheckProc(clientData, flags)
     for (filePtr = firstFileHandlerPtr; filePtr != NULL;
 	    filePtr = filePtr->nextPtr) {
 	if (filePtr->mask != 0) {
-	    filePtr->readyMask = Tcl_FileReady(filePtr->file, filePtr->mask);
+            filePtr->readyMask = Tcl_FileReady(filePtr->file, filePtr->mask);
 	    if (filePtr->readyMask != 0) {
 		fileEvPtr = (FileHandlerEvent *) ckalloc(
 			sizeof(FileHandlerEvent));
@@ -633,7 +633,7 @@ Tcl_CreateTimerHandler(milliseconds, proc, clientData)
      * Compute when the event should fire.
      */
 
-    TclGetTime(&timerHandlerPtr->time);
+    TclpGetTime(&timerHandlerPtr->time);
     timerHandlerPtr->time.sec += milliseconds/1000;
     timerHandlerPtr->time.usec += (milliseconds%1000)*1000;
     if (timerHandlerPtr->time.usec >= 1000000) {
@@ -755,7 +755,7 @@ Tcl_CreateModalTimeout(milliseconds, proc, clientData)
      * of the handler.
      */
 
-    TclGetTime(&timerHandlerPtr->time);
+    TclpGetTime(&timerHandlerPtr->time);
     timerHandlerPtr->time.sec += milliseconds/1000;
     timerHandlerPtr->time.usec += (milliseconds%1000)*1000;
     if (timerHandlerPtr->time.usec >= 1000000) {
@@ -860,7 +860,7 @@ TimerHandlerSetupProc(clientData, flags)
 	return;
     }
 
-    TclGetTime(&blockTime);
+    TclpGetTime(&blockTime);
     blockTime.sec = timerHandlerPtr->time.sec - blockTime.sec;
     blockTime.usec = timerHandlerPtr->time.usec - blockTime.usec;
     if (blockTime.usec < 0) {
@@ -910,7 +910,7 @@ TimerHandlerCheckProc(clientData, flags)
     gotTime = 0;
     timerHandlerPtr = firstTimerHandlerPtr;
     if ((flags & TCL_TIMER_EVENTS) && (timerHandlerPtr != NULL)) {
-	TclGetTime(&curTime);
+	TclpGetTime(&curTime);
 	gotTime = 1;
 	if ((timerHandlerPtr->time.sec < curTime.sec)
 		|| ((timerHandlerPtr->time.sec == curTime.sec)
@@ -921,7 +921,7 @@ TimerHandlerCheckProc(clientData, flags)
     timerHandlerPtr = firstModalHandlerPtr;
     if (timerHandlerPtr != NULL) {
 	if (!gotTime) {
-	    TclGetTime(&curTime);
+	    TclpGetTime(&curTime);
 	}
 	if ((timerHandlerPtr->time.sec < curTime.sec)
 		|| ((timerHandlerPtr->time.sec == curTime.sec)
@@ -1992,9 +1992,11 @@ Tcl_VwaitCmd(clientData, interp, argc, argv)
 		argv[0], " name\"", (char *) NULL);
 	return TCL_ERROR;
     }
-    Tcl_TraceVar(interp, argv[1],
+    if (Tcl_TraceVar(interp, argv[1],
 	    TCL_GLOBAL_ONLY|TCL_TRACE_WRITES|TCL_TRACE_UNSETS,
-	    VwaitVarProc, (ClientData) &done);
+	    VwaitVarProc, (ClientData) &done) != TCL_OK) {
+	return TCL_ERROR;
+    };
     done = 0;
     foundEvent = 1;
     while (!done && foundEvent) {
@@ -2134,7 +2136,7 @@ TclWaitForFile(file, mask, timeout)
      */
 
     if (timeout > 0) {
-	TclGetTime(&now);
+	TclpGetTime(&now);
 	abortTime.sec = now.sec + timeout/1000;
 	abortTime.usec = now.usec + (timeout%1000)*1000;
 	if (abortTime.usec >= 1000000) {
@@ -2149,7 +2151,7 @@ TclWaitForFile(file, mask, timeout)
      */
 
     while (1) {
-	Tcl_WatchFile(file, mask);
+        Tcl_WatchFile(file, mask);
 	if (timeout > 0) {
 	    blockTime.sec = abortTime.sec - now.sec;
 	    blockTime.usec = abortTime.usec - now.usec;
@@ -2169,14 +2171,14 @@ TclWaitForFile(file, mask, timeout)
 	} else {
 	    Tcl_WaitForEvent((Tcl_Time *) NULL);
 	}
-	present = Tcl_FileReady(file, mask);
+        present = Tcl_FileReady(file, mask);
 	if (present != 0) {
 	    break;
 	}
 	if (timeout == 0) {
 	    break;
 	}
-	TclGetTime(&now);
+	TclpGetTime(&now);
 	if ((abortTime.sec < now.sec)
 		|| ((abortTime.sec == now.sec)
 		&& (abortTime.usec <= now.usec))) {
