@@ -7,12 +7,12 @@
  *      Unix Tcl normally hands off to the Unix OS.
  *
  * Copyright (c) 1993-1994 Lockheed Missle & Space Company, AI Center
- * Copyright (c) 1994-1997 Sun Microsystems, Inc.
+ * Copyright (c) 1994-1996 Sun Microsystems, Inc.
  *
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * RCS: @(#) $Id: tclMacUnix.c,v 1.3.12.1 2001/04/04 21:22:19 hobbs Exp $
+ * SCCS: @(#) tclMacUnix.c 1.55 96/09/14 19:14:17
  */
 
 #include <Files.h>
@@ -51,6 +51,87 @@
 #define noSourceErr		501
 #define isDirErr		502
 
+/*
+ * Static functions in this file.
+ */
+
+static int	GlobArgs _ANSI_ARGS_((Tcl_Interp *interp,
+		    int *argc, char ***argv));
+
+/*
+ *----------------------------------------------------------------------
+ *
+ * GlobArgs --
+ *
+ *	The following function was taken from Peter Keleher's Alpha
+ *	Editor.  *argc should only count the end arguments that should
+ *	be globed.  argv should be incremented to point to the first
+ *	arg to be globed.
+ *
+ * Results:
+ *	Returns 'true' if it worked & memory was allocated, else 'false'.
+ *
+ * Side effects:
+ *	argv will be alloced, the call will need to release the memory
+ *
+ *----------------------------------------------------------------------
+ */
+ 
+static int
+GlobArgs(
+    Tcl_Interp *interp,		/* Tcl interpreter. */
+    int *argc,			/* Number of arguments. */
+    char ***argv)		/* Argument strings. */
+{
+    int res, len;
+    char *list;
+	
+    /*
+     * Places the globbed args all into 'interp->result' as a list.
+     */
+    res = Tcl_GlobCmd(NULL, interp, *argc + 1, *argv - 1);
+    if (res != TCL_OK) {
+	return false;
+    }
+    len = strlen(interp->result);
+    list = (char *) ckalloc(len + 1);
+    strcpy(list, interp->result);
+    Tcl_ResetResult(interp);
+	
+    res = Tcl_SplitList(interp, list, argc, argv);
+    ckfree((char *) list);
+    if (res != TCL_OK) {
+	return false;
+    }
+    return true;
+}
+
+/*
+ *----------------------------------------------------------------------
+ *
+ * Tcl_CpCmd --
+ *
+ *	This procedure is invoked to process the "cp" Tcl command.
+ *	See the user documentation for the "file copy" command for 
+ *	details on what it does.
+ *
+ * Results:
+ *	A standard Tcl result.
+ *
+ * Side effects:
+ *	See the user documentation.
+ *
+ *----------------------------------------------------------------------
+ */
+int
+Tcl_CpCmd(
+    ClientData dummy,			/* Not used. */
+    Tcl_Interp *interp,			/* Current interpreter. */
+    int argc,				/* Number of arguments. */
+    char **argv)			/* Argument strings. */
+{
+    return TclFileCopyCmd(interp, argc-1, argv+1);
+}
 
 /*
  *----------------------------------------------------------------------
@@ -84,24 +165,24 @@ Tcl_EchoCmd(
         return TCL_ERROR;
     }
     for (i = 1; i < argc; i++) {
-	result = Tcl_WriteChars(chan, argv[i], -1);
+	result = Tcl_Write(chan, argv[i], -1);
 	if (result < 0) {
 	    Tcl_AppendResult(interp, "echo: ", Tcl_GetChannelName(chan),
 		    ": ", Tcl_PosixError(interp), (char *) NULL);
 	    return TCL_ERROR;
 	}
         if (i < (argc - 1)) {
-	    Tcl_WriteChars(chan, " ", -1);
+	    Tcl_Write(chan, " ", -1);
 	}
     }
-    Tcl_WriteChars(chan, "\n", -1);
+    Tcl_Write(chan, "\n", -1);
     return TCL_OK;
 }
 
 /*
  *----------------------------------------------------------------------
  *
- * Tcl_LsObjCmd --
+ * Tcl_LsCmd --
  *
  *	This procedure is invoked to process the "ls" Tcl command.
  *	See the user documentation for details on what it does.
@@ -115,16 +196,17 @@ Tcl_EchoCmd(
  *----------------------------------------------------------------------
  */
 int
-Tcl_LsObjCmd(
+Tcl_LsCmd(
     ClientData dummy,			/* Not used. */
     Tcl_Interp *interp,			/* Current interpreter. */
-    int objc,				/* Number of arguments. */
-    Tcl_Obj *CONST objv[])		/* Argument strings. */
+    int argc,				/* Number of arguments. */
+    char **argv)			/* Argument strings. */
 {
 #define STRING_LENGTH 80
 #define CR '\n'
     int i, j;
     int fieldLength, len = 0, maxLen = 0, perLine;
+    char **origArgv = argv;
     OSErr err;
     CInfoPBRec paramBlock;
     HFileInfo *hpb = (HFileInfo *)&paramBlock;
@@ -133,27 +215,24 @@ Tcl_LsObjCmd(
     char theLine[STRING_LENGTH + 2];
     int fFlag = false, pFlag = false, aFlag = false, lFlag = false,
 	cFlag = false, hFlag = false;
-    char *argv;
-    Tcl_Obj *newObjv[2], *resultObjPtr;
 
     /*
      * Process command flags.  End if argument doesn't start
      * with a dash or is a dash by itself.  The remaining arguments
      * should be files.
      */
-    for (i = 1; i < objc; i++) {
-    	argv = Tcl_GetString(objv[i]);
-	if (argv[0] != '-') {
+    for (i = 1; i < argc; i++) {
+	if (argv[i][0] != '-') {
 	    break;
 	}
 		
-	if (!strcmp(argv, "-")) {
+	if (!strcmp(argv[i], "-")) {
 	    i++;
 	    break;
 	}
 		
-	for (j = 1 ; argv[j] ; ++j) {
-	    switch(argv[j]) {
+	for (j = 1 ; argv[i][j] ; ++j) {
+	    switch(argv[i][j]) {
 	    case 'a':
 	    case 'A':
 		aFlag = true;
@@ -185,34 +264,24 @@ Tcl_LsObjCmd(
 	}
     }
 
-    objv += i;
-    objc -= i;
+    argv += i;
+    argc -= i;
 
     /*
      * No file specifications means we search for all files.
      * Glob will be doing most of the work.
      */
-     if (!objc) {
-	objc = 1;
-	newObjv[0] = Tcl_NewStringObj("*", -1);
-	newObjv[1] = NULL;
-	objv = newObjv;
+     if (!argc) {
+	argc = 1;
+	argv = origArgv;
+	strcpy(argv[0], "*");
     }
 
-    if (Tcl_GlobObjCmd(NULL, interp, objc + 1, objv - 1) != TCL_OK) {
-    	Tcl_ResetResult(interp);
-    	return TCL_ERROR;
+    if (!GlobArgs(interp, &argc, &argv)) {
+	Tcl_ResetResult(interp);
+	return TCL_ERROR;
     }
 
-    resultObjPtr = Tcl_GetObjResult(interp);
-    Tcl_IncrRefCount(resultObjPtr);
-    if (Tcl_ListObjGetElements(interp, resultObjPtr, &objc, (Tcl_Obj ***)&objv) != TCL_OK) {
-    	Tcl_DecrRefCount(resultObjPtr);
-    	return TCL_ERROR;
-    }
-
-    Tcl_ResetResult(interp);
-
     /*
      * There are two major methods for listing files: the long
      * method and the normal method.
@@ -222,9 +291,6 @@ Tcl_LsObjCmd(
 	char	lineTag;
 	long	size;
 	unsigned short flags;
-	Tcl_Obj *objPtr;
-	char *string;
-	int length;
 
 	/*
 	 * Print the header for long listing.
@@ -239,8 +305,8 @@ Tcl_LsObjCmd(
 		    NULL);
 	}
 		
-	for (i = 0; i < objc; i++) {
-	    strcpy(theFile, Tcl_GetString(objv[i]));
+	for (i = 0; i < argc; i++) {
+	    strcpy(theFile, argv[i]);
 			
 	    c2pstr(theFile);
 	    hpb->ioCompletion = NULL;
@@ -308,10 +374,11 @@ Tcl_LsObjCmd(
 	    
 	}
 		
-	objPtr = Tcl_GetObjResult(interp);
-	string = Tcl_GetStringFromObj(objPtr, &length);
-	if ((length > 0) && (string[length - 1] == '\n')) {
-	    Tcl_SetObjLength(objPtr, length - 1);
+	if ((interp->result != NULL) && (*(interp->result) != '\0')) {
+	    int slen = strlen(interp->result);
+	    if (interp->result[slen - 1] == '\n') {
+		interp->result[slen - 1] = '\0';
+	    }
 	}
     } else {
 	/*
@@ -329,9 +396,8 @@ Tcl_LsObjCmd(
 	    perLine = 1;
 	    fieldLength = STRING_LENGTH;
 	} else {
-	    for (i = 0; i < objc; i++) {
-	    	argv = Tcl_GetString(objv[i]);
-		len = strlen(argv);
+	    for (i = 0; i < argc; i++) {
+		len = strlen(argv[i]);
 		if (len > maxLen) {
 		    maxLen = len;
 		}
@@ -343,8 +409,8 @@ Tcl_LsObjCmd(
 	argCount = 0;
 	linePos = 0;
 	memset(theLine, ' ', STRING_LENGTH);
-	while (argCount < objc) {
-	    strcpy(theFile, Tcl_GetString(objv[argCount]));
+	while (argCount < argc) {
+	    strcpy(theFile, argv[argCount]);
 			
 	    c2pstr(theFile);
 	    hpb->ioCompletion = NULL;
@@ -418,8 +484,177 @@ Tcl_LsObjCmd(
 	    }
 	}
     }
-
-    Tcl_DecrRefCount(resultObjPtr);
-    	
+	
+    ckfree((char *) argv);
+	
     return TCL_OK;
 }
+
+/*
+ *----------------------------------------------------------------------
+ *
+ * Tcl_MkdirCmd --
+ *
+ *	This procedure is invoked to process the "mkdir" Tcl command.
+ *	See the user documentation for details on what it does.
+ *
+ * Results:
+ *	A standard Tcl result.
+ *
+ * Side effects:
+ *	See the user documentation.
+ *
+ *----------------------------------------------------------------------
+ */
+int
+Tcl_MkdirCmd (
+    ClientData dummy,			/* Not used. */
+    Tcl_Interp *interp,			/* Current interpreter. */
+    int argc,				/* Number of arguments. */
+    char **argv)			/* Argument strings. */
+{
+    if (argc < 2) {
+	Tcl_AppendResult(interp, "wrong # args: should be ", argv[0], 
+	    " path ?path ...?", (char *) NULL);
+	return TCL_ERROR;
+    }
+
+    if ((argc > 2) && (!strcmp(argv[1], "-path"))) {
+	argv++;
+	argc--;
+    }
+
+    return TclFileMakeDirsCmd(interp, argc-1, argv+1);
+}
+
+/*
+ *----------------------------------------------------------------------
+ *
+ * Tcl_MvCmd --
+ *
+ *	This procedure is invoked to process the "cp" Tcl command.
+ *	See the user documentation for details on what it does.
+ *
+ * Results:
+ *	A standard Tcl result.
+ *
+ * Side effects:
+ *	See the user documentation.
+ *
+ *----------------------------------------------------------------------
+ */
+
+int
+Tcl_MvCmd(
+    ClientData dummy,			/* Not used. */
+    Tcl_Interp *interp,			/* Current interpreter. */
+    int argc,				/* Number of arguments. */
+    char **argv)			/* Argument strings. */
+{
+    return TclFileRenameCmd(interp, argc-1, argv+1);
+}
+
+/*
+ *----------------------------------------------------------------------
+ *
+ * Tcl_RmCmd --
+ *
+ *	This procedure is invoked to process the "rm" Tcl command.
+ *	See the user documentation for details on what it does.
+ *
+ * Results:
+ *	A standard Tcl result.
+ *
+ * Side effects:
+ *	See the user documentation.
+ *
+ *----------------------------------------------------------------------
+ */
+
+int
+Tcl_RmCmd(
+    ClientData dummy,			/* Not used. */
+    Tcl_Interp *interp,			/* Current interpreter. */
+    int argc,				/* Number of arguments. */
+    char **argv)			/* Argument strings. */
+{
+    int newArgc, result;
+    char **newArgv;
+    char *list;
+
+    if (argc < 2) {
+	Tcl_AppendResult(interp, "wrong # args: ", argv[0], 
+	    " ?-force? path ?path ...?", (char *) NULL);
+	return TCL_ERROR;
+    }
+    if ((argc > 2) && (!strcmp(argv[1], "-nocomplain"))) {
+	argv++;
+	argc--;
+    }
+
+    if ((argc > 2) && (!strcmp(argv[1], "-force"))) {
+	result = Tcl_GlobCmd(NULL, interp, argc + 1, argv - 1);
+	if (result != TCL_OK) {
+	    return result;
+	}
+	list = (char *) ckalloc(strlen(interp->result) + strlen("-force ") + 1);
+	strcpy(list, "-force ");
+	strcpy(list + strlen("-force "), interp->result);
+	Tcl_ResetResult(interp);
+	
+	result = Tcl_SplitList(interp, list, &newArgc, &newArgv);
+	ckfree((char *) list);
+	if (result != TCL_OK) {
+	    return result;
+	}
+
+	result = TclFileDeleteCmd(interp, newArgc, newArgv);
+	ckfree((char *) newArgv);
+    } else {
+	newArgc = argc-1;
+	newArgv = argv+1;
+	if (!GlobArgs(interp, &newArgc, &newArgv)) {
+	    return TCL_OK;
+	}
+	result = TclFileDeleteCmd(interp, newArgc, newArgv);
+	ckfree((char *) newArgv);
+    }
+    
+    return result;
+}
+
+/*
+ *----------------------------------------------------------------------
+ *
+ * Tcl_RmdirCmd --
+ *
+ *     Implements the Tcl rmdir command:
+ *
+ * Results:
+ *	Standard TCL results, may return the UNIX system error message.
+ *
+ * Side effects:
+ *	See the user documentation.
+ *
+ *----------------------------------------------------------------------
+ */
+
+int
+Tcl_RmdirCmd (dummy, interp, argc, argv)
+    ClientData dummy;			/* Not used. */
+    Tcl_Interp *interp;			/* Current interpreter. */
+    int argc;				/* Number of arguments. */
+    char **argv;			/* Argument strings. */
+{
+    if (argc < 2) {
+	Tcl_AppendResult(interp, "wrong # args: ", argv[0], 
+	    " ?-force? path ?path ...?", (char *) NULL);
+	return TCL_ERROR;
+    }
+    if ((argc > 2) && (!strcmp(argv[1], "-nocomplain"))) {
+	argv++;
+	argc--;
+    }
+
+    return TclFileDeleteCmd(interp, argc-1, argv+1);
+}
