@@ -9,7 +9,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * SCCS: @(#) tclUnixFile.c 1.38 96/04/18 08:43:51
+ * SCCS: @(#) tclUnixFile.c 1.39 96/09/12 14:57:31
  */
 
 #include "tclInt.h"
@@ -414,8 +414,11 @@ TclSeekFile(file, offset, whence)
  */
 
 Tcl_File
-TclCreateTempFile(contents)
+TclCreateTempFile(contents, namePtr)
     char *contents;		/* String to write into temp file, or NULL. */
+    Tcl_DString *namePtr;	/* If non-NULL, pointer to initialized 
+				 * DString that is filled with the name of 
+				 * the temp file that was created. */
 {
     char fileName[L_tmpnam];
     Tcl_File file;
@@ -438,6 +441,9 @@ TclCreateTempFile(contents)
 	}
 	lseek(fd, 0, SEEK_SET);
     }
+    if (namePtr != NULL) {
+	Tcl_DStringAppend(namePtr, fileName, -1);
+    }
     return file;
 }
 
